# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/image_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import hardware_generation_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_hardware__generation__pb2
from yandex.cloud.compute.v1 import image_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_image__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/compute/v1/image_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\x31yandex/cloud/compute/v1/hardware_generation.proto\x1a#yandex/cloud/compute/v1/image.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"s\n\x1dGetImageLatestByFamilyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x31\n\x06\x66\x61mily\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\"\xab\x01\n\x11ListImagesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"]\n\x12ListImagesResponse\x12.\n\x06images\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.compute.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xcf\x05\n\x12\x43reateImageRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x37.yandex.cloud.compute.v1.CreateImageRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x31\n\x06\x66\x61mily\x18\x05 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x30\n\rmin_disk_size\x18\x06 \x01(\x03\x42\x19\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12\x1d\n\x0bproduct_ids\x18\x07 \x03(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\x08image_id\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1b\n\x07\x64isk_id\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\n \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\r\n\x03uri\x18\x0b \x01(\tH\x00\x12\'\n\x02os\x18\x0c \x01(\x0b\x32\x1b.yandex.cloud.compute.v1.Os\x12\x0e\n\x06pooled\x18\x11 \x01(\x08\x12H\n\x13hardware_generation\x18\x12 \x01(\x0b\x32+.yandex.cloud.compute.v1.HardwareGeneration\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x06source\x12\x04\xc0\xc1\x31\x01J\x04\x08\r\x10\x11\"\'\n\x13\x43reateImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"\xa9\x03\n\x12UpdateImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x30\n\rmin_disk_size\x18\x05 \x01(\x03\x42\x19\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12\x8c\x01\n\x06labels\x18\x06 \x03(\x0b\x32\x37.yandex.cloud.compute.v1.UpdateImageRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13UpdateImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"4\n\x12\x44\x65leteImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"z\n\x1aListImageOperationsRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x1bListImageOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe6\r\n\x0cImageService\x12v\n\x03Get\x12(.yandex.cloud.compute.v1.GetImageRequest\x1a\x1e.yandex.cloud.compute.v1.Image\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/compute/v1/images/{image_id}\x12\x96\x01\n\x11GetLatestByFamily\x12\x36.yandex.cloud.compute.v1.GetImageLatestByFamilyRequest\x1a\x1e.yandex.cloud.compute.v1.Image\")\x82\xd3\xe4\x93\x02#\x12!/compute/v1/images:latestByFamily\x12{\n\x04List\x12*.yandex.cloud.compute.v1.ListImagesRequest\x1a+.yandex.cloud.compute.v1.ListImagesResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/compute/v1/images\x12\x97\x01\n\x06\x43reate\x12+.yandex.cloud.compute.v1.CreateImageRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*\x1c\n\x13\x43reateImageMetadata\x12\x05Image\x82\xd3\xe4\x93\x02\x17\"\x12/compute/v1/images:\x01*\x12\xa2\x01\n\x06Update\x12+.yandex.cloud.compute.v1.UpdateImageRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\x1c\n\x13UpdateImageMetadata\x12\x05Image\x82\xd3\xe4\x93\x02\"2\x1d/compute/v1/images/{image_id}:\x01*\x12\xaf\x01\n\x06\x44\x65lete\x12+.yandex.cloud.compute.v1.DeleteImageRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*,\n\x13\x44\x65leteImageMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f*\x1d/compute/v1/images/{image_id}\x12\xad\x01\n\x0eListOperations\x12\x33.yandex.cloud.compute.v1.ListImageOperationsRequest\x1a\x34.yandex.cloud.compute.v1.ListImageOperationsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/compute/v1/images/{image_id}/operations\x12\xb2\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/compute/v1/images/{resource_id}:listAccessBindings\x12\xf1\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x37\"2/compute/v1/images/{resource_id}:setAccessBindings:\x01*\x12\xfd\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02:\"5/compute/v1/images/{resource_id}:updateAccessBindings:\x01*Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.image_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _GETIMAGEREQUEST.fields_by_name['image_id']._options = None
  _GETIMAGEREQUEST.fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETIMAGELATESTBYFAMILYREQUEST.fields_by_name['folder_id']._options = None
  _GETIMAGELATESTBYFAMILYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETIMAGELATESTBYFAMILYREQUEST.fields_by_name['family']._options = None
  _GETIMAGELATESTBYFAMILYREQUEST.fields_by_name['family']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _LISTIMAGESREQUEST.fields_by_name['folder_id']._options = None
  _LISTIMAGESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTIMAGESREQUEST.fields_by_name['page_size']._options = None
  _LISTIMAGESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTIMAGESREQUEST.fields_by_name['page_token']._options = None
  _LISTIMAGESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTIMAGESREQUEST.fields_by_name['filter']._options = None
  _LISTIMAGESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTIMAGESREQUEST.fields_by_name['order_by']._options = None
  _LISTIMAGESREQUEST.fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _CREATEIMAGEREQUEST_LABELSENTRY._options = None
  _CREATEIMAGEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEIMAGEREQUEST.oneofs_by_name['source']._options = None
  _CREATEIMAGEREQUEST.oneofs_by_name['source']._serialized_options = b'\300\3011\001'
  _CREATEIMAGEREQUEST.fields_by_name['folder_id']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEIMAGEREQUEST.fields_by_name['name']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEIMAGEREQUEST.fields_by_name['description']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEIMAGEREQUEST.fields_by_name['labels']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _CREATEIMAGEREQUEST.fields_by_name['family']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['family']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATEIMAGEREQUEST.fields_by_name['min_disk_size']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['min_disk_size']._serialized_options = b'\372\3071\0254194304-4398046511104'
  _CREATEIMAGEREQUEST.fields_by_name['product_ids']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['product_ids']._serialized_options = b'\212\3101\004<=50'
  _CREATEIMAGEREQUEST.fields_by_name['image_id']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['image_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEIMAGEREQUEST.fields_by_name['disk_id']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['disk_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEIMAGEREQUEST.fields_by_name['snapshot_id']._options = None
  _CREATEIMAGEREQUEST.fields_by_name['snapshot_id']._serialized_options = b'\212\3101\004<=50'
  _UPDATEIMAGEREQUEST_LABELSENTRY._options = None
  _UPDATEIMAGEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEIMAGEREQUEST.fields_by_name['image_id']._options = None
  _UPDATEIMAGEREQUEST.fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEIMAGEREQUEST.fields_by_name['name']._options = None
  _UPDATEIMAGEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEIMAGEREQUEST.fields_by_name['description']._options = None
  _UPDATEIMAGEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEIMAGEREQUEST.fields_by_name['min_disk_size']._options = None
  _UPDATEIMAGEREQUEST.fields_by_name['min_disk_size']._serialized_options = b'\372\3071\0254194304-4398046511104'
  _UPDATEIMAGEREQUEST.fields_by_name['labels']._options = None
  _UPDATEIMAGEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _DELETEIMAGEREQUEST.fields_by_name['image_id']._options = None
  _DELETEIMAGEREQUEST.fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTIMAGEOPERATIONSREQUEST.fields_by_name['image_id']._options = None
  _LISTIMAGEOPERATIONSREQUEST.fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTIMAGEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTIMAGEOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTIMAGEOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTIMAGEOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _IMAGESERVICE.methods_by_name['Get']._options = None
  _IMAGESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/compute/v1/images/{image_id}'
  _IMAGESERVICE.methods_by_name['GetLatestByFamily']._options = None
  _IMAGESERVICE.methods_by_name['GetLatestByFamily']._serialized_options = b'\202\323\344\223\002#\022!/compute/v1/images:latestByFamily'
  _IMAGESERVICE.methods_by_name['List']._options = None
  _IMAGESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\024\022\022/compute/v1/images'
  _IMAGESERVICE.methods_by_name['Create']._options = None
  _IMAGESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateImageMetadata\022\005Image\202\323\344\223\002\027\"\022/compute/v1/images:\001*'
  _IMAGESERVICE.methods_by_name['Update']._options = None
  _IMAGESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateImageMetadata\022\005Image\202\323\344\223\002\"2\035/compute/v1/images/{image_id}:\001*'
  _IMAGESERVICE.methods_by_name['Delete']._options = None
  _IMAGESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteImageMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037*\035/compute/v1/images/{image_id}'
  _IMAGESERVICE.methods_by_name['ListOperations']._options = None
  _IMAGESERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002*\022(/compute/v1/images/{image_id}/operations'
  _IMAGESERVICE.methods_by_name['ListAccessBindings']._options = None
  _IMAGESERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\0025\0223/compute/v1/images/{resource_id}:listAccessBindings'
  _IMAGESERVICE.methods_by_name['SetAccessBindings']._options = None
  _IMAGESERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\0027\"2/compute/v1/images/{resource_id}:setAccessBindings:\001*'
  _IMAGESERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _IMAGESERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002:\"5/compute/v1/images/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETIMAGEREQUEST']._serialized_start=363
  _globals['_GETIMAGEREQUEST']._serialized_end=412
  _globals['_GETIMAGELATESTBYFAMILYREQUEST']._serialized_start=414
  _globals['_GETIMAGELATESTBYFAMILYREQUEST']._serialized_end=529
  _globals['_LISTIMAGESREQUEST']._serialized_start=532
  _globals['_LISTIMAGESREQUEST']._serialized_end=703
  _globals['_LISTIMAGESRESPONSE']._serialized_start=705
  _globals['_LISTIMAGESRESPONSE']._serialized_end=798
  _globals['_CREATEIMAGEREQUEST']._serialized_start=801
  _globals['_CREATEIMAGEREQUEST']._serialized_end=1520
  _globals['_CREATEIMAGEREQUEST_LABELSENTRY']._serialized_start=1453
  _globals['_CREATEIMAGEREQUEST_LABELSENTRY']._serialized_end=1498
  _globals['_CREATEIMAGEMETADATA']._serialized_start=1522
  _globals['_CREATEIMAGEMETADATA']._serialized_end=1561
  _globals['_UPDATEIMAGEREQUEST']._serialized_start=1564
  _globals['_UPDATEIMAGEREQUEST']._serialized_end=1989
  _globals['_UPDATEIMAGEREQUEST_LABELSENTRY']._serialized_start=1453
  _globals['_UPDATEIMAGEREQUEST_LABELSENTRY']._serialized_end=1498
  _globals['_UPDATEIMAGEMETADATA']._serialized_start=1991
  _globals['_UPDATEIMAGEMETADATA']._serialized_end=2030
  _globals['_DELETEIMAGEREQUEST']._serialized_start=2032
  _globals['_DELETEIMAGEREQUEST']._serialized_end=2084
  _globals['_DELETEIMAGEMETADATA']._serialized_start=2086
  _globals['_DELETEIMAGEMETADATA']._serialized_end=2125
  _globals['_LISTIMAGEOPERATIONSREQUEST']._serialized_start=2127
  _globals['_LISTIMAGEOPERATIONSREQUEST']._serialized_end=2249
  _globals['_LISTIMAGEOPERATIONSRESPONSE']._serialized_start=2251
  _globals['_LISTIMAGEOPERATIONSRESPONSE']._serialized_end=2360
  _globals['_IMAGESERVICE']._serialized_start=2363
  _globals['_IMAGESERVICE']._serialized_end=4129
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Peering(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEERING_SUBNET_FIELD_NUMBER: builtins.int
    PEER_IP_FIELD_NUMBER: builtins.int
    CLOUD_IP_FIELD_NUMBER: builtins.int
    PEER_BGP_ASN_FIELD_NUMBER: builtins.int
    CLOUD_BGP_ASN_FIELD_NUMBER: builtins.int
    PEER_BGP_MD5_KEY_FIELD_NUMBER: builtins.int
    peering_subnet: builtins.str
    """PeeringSubnet.
    It's an ip with format ipPrefix/length where address part of ipPrefix is 0.
    """
    peer_ip: builtins.str
    """PeerIp.
    It's an ip with just an ipAddress format without mask.
    """
    cloud_ip: builtins.str
    """CloudIp.
    It's an ip with just an ipAddress format without mask.
    """
    peer_bgp_asn: builtins.int
    """PeerBgpAsn.
    PeerAsn excluding rfc5398 (excluding 64496 - 64511 and 65536 - 65551).
    """
    cloud_bgp_asn: builtins.int
    """CloudBgpAsn."""
    peer_bgp_md5_key: builtins.str
    """PeerBgpMd5Key.
    Optional.
    """
    def __init__(
        self,
        *,
        peering_subnet: builtins.str = ...,
        peer_ip: builtins.str = ...,
        cloud_ip: builtins.str = ...,
        peer_bgp_asn: builtins.int = ...,
        cloud_bgp_asn: builtins.int = ...,
        peer_bgp_md5_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cloud_bgp_asn", b"cloud_bgp_asn", "cloud_ip", b"cloud_ip", "peer_bgp_asn", b"peer_bgp_asn", "peer_bgp_md5_key", b"peer_bgp_md5_key", "peer_ip", b"peer_ip", "peering_subnet", b"peering_subnet"]) -> None: ...

global___Peering = Peering



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.ai.dataset.v1.dataset_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class DatasetServiceStub:
    """A set of methods for managing datasets."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Describe: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetResponse,
    ]
    """Returns dataset information by dataset id."""

    Validate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ValidateDatasetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts dataset validation process."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetResponse,
    ]
    """Creates dataset."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetResponse,
    ]
    """Updates dataset."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetResponse,
    ]
    """Deletes dataset."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsResponse,
    ]
    """Lists datasets in specified folder."""

    ListUploadFormats: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsResponse,
    ]
    """Lists supported upload formats for the specified dataset task type."""

    GetUploadDraftUrl: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlResponse,
    ]
    """Returns an S3 presigned URL for dataset upload.
    This method only applicable if the dataset size does not exceed 5GB.
    """

    StartMultipartUploadDraft: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftResponse,
    ]
    """Returns a list of S3 presigned URLs for multipart upload of dataset."""

    FinishMultipartUploadDraft: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftResponse,
    ]
    """Finishes multipart upload of the dataset."""

class DatasetServiceAsyncStub:
    """A set of methods for managing datasets."""

    Describe: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetResponse,
    ]
    """Returns dataset information by dataset id."""

    Validate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ValidateDatasetRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Starts dataset validation process."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetResponse,
    ]
    """Creates dataset."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetResponse,
    ]
    """Updates dataset."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetResponse,
    ]
    """Deletes dataset."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsResponse,
    ]
    """Lists datasets in specified folder."""

    ListUploadFormats: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsResponse,
    ]
    """Lists supported upload formats for the specified dataset task type."""

    GetUploadDraftUrl: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlResponse,
    ]
    """Returns an S3 presigned URL for dataset upload.
    This method only applicable if the dataset size does not exceed 5GB.
    """

    StartMultipartUploadDraft: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftResponse,
    ]
    """Returns a list of S3 presigned URLs for multipart upload of dataset."""

    FinishMultipartUploadDraft: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftRequest,
        yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftResponse,
    ]
    """Finishes multipart upload of the dataset."""

class DatasetServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing datasets."""

    @abc.abstractmethod
    def Describe(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.DescribeDatasetResponse]]:
        """Returns dataset information by dataset id."""

    @abc.abstractmethod
    def Validate(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.ValidateDatasetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Starts dataset validation process."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.CreateDatasetResponse]]:
        """Creates dataset."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.UpdateDatasetResponse]]:
        """Updates dataset."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.DeleteDatasetResponse]]:
        """Deletes dataset."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListDatasetsResponse]]:
        """Lists datasets in specified folder."""

    @abc.abstractmethod
    def ListUploadFormats(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.ListUploadFormatsResponse]]:
        """Lists supported upload formats for the specified dataset task type."""

    @abc.abstractmethod
    def GetUploadDraftUrl(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.GetUploadDraftUrlResponse]]:
        """Returns an S3 presigned URL for dataset upload.
        This method only applicable if the dataset size does not exceed 5GB.
        """

    @abc.abstractmethod
    def StartMultipartUploadDraft(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.StartMultipartUploadDraftResponse]]:
        """Returns a list of S3 presigned URLs for multipart upload of dataset."""

    @abc.abstractmethod
    def FinishMultipartUploadDraft(
        self,
        request: yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftResponse, collections.abc.Awaitable[yandex.cloud.ai.dataset.v1.dataset_service_pb2.FinishMultipartUploadDraftResponse]]:
        """Finishes multipart upload of the dataset."""

def add_DatasetServiceServicer_to_server(servicer: DatasetServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.ai.llm.v1alpha.llm_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InstructRequest(google.protobuf.message.Message):
    """Request for instructing the model to generate text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    GENERATION_OPTIONS_FIELD_NUMBER: builtins.int
    INSTRUCTION_TEXT_FIELD_NUMBER: builtins.int
    INSTRUCTION_URI_FIELD_NUMBER: builtins.int
    REQUEST_TEXT_FIELD_NUMBER: builtins.int
    model: builtins.str
    """The name or identifier of the model to be used for text generation.
    Possible value for now: `general`.
    """
    instruction_text: builtins.str
    """The text-based instruction for text generation."""
    instruction_uri: builtins.str
    """A URI containing instructions for text generation."""
    request_text: builtins.str
    """The text-based request for text generation."""
    @property
    def generation_options(self) -> yandex.cloud.ai.llm.v1alpha.llm_pb2.GenerationOptions:
        """Configuration options for text generation."""

    def __init__(
        self,
        *,
        model: builtins.str = ...,
        generation_options: yandex.cloud.ai.llm.v1alpha.llm_pb2.GenerationOptions | None = ...,
        instruction_text: builtins.str = ...,
        instruction_uri: builtins.str = ...,
        request_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Instruction", b"Instruction", "Request", b"Request", "generation_options", b"generation_options", "instruction_text", b"instruction_text", "instruction_uri", b"instruction_uri", "request_text", b"request_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Instruction", b"Instruction", "Request", b"Request", "generation_options", b"generation_options", "instruction_text", b"instruction_text", "instruction_uri", b"instruction_uri", "model", b"model", "request_text", b"request_text"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["Instruction", b"Instruction"]) -> typing.Literal["instruction_text", "instruction_uri"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["Request", b"Request"]) -> typing.Literal["request_text"] | None: ...

global___InstructRequest = InstructRequest

@typing.final
class InstructResponse(google.protobuf.message.Message):
    """Response containing generated text alternatives and token count."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALTERNATIVES_FIELD_NUMBER: builtins.int
    NUM_PROMPT_TOKENS_FIELD_NUMBER: builtins.int
    num_prompt_tokens: builtins.int
    """The number of tokens used in the prompt, including both the [instruction_text] and [request_text]."""
    @property
    def alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.llm.v1alpha.llm_pb2.Alternative]:
        """A list of alternative text responses."""

    def __init__(
        self,
        *,
        alternatives: collections.abc.Iterable[yandex.cloud.ai.llm.v1alpha.llm_pb2.Alternative] | None = ...,
        num_prompt_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alternatives", b"alternatives", "num_prompt_tokens", b"num_prompt_tokens"]) -> None: ...

global___InstructResponse = InstructResponse

@typing.final
class ChatRequest(google.protobuf.message.Message):
    """Request to engage in a chat conversation with a text generation model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    GENERATION_OPTIONS_FIELD_NUMBER: builtins.int
    INSTRUCTION_TEXT_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    model: builtins.str
    """The name or identifier of the model to be used for the chat.
    Possible value for now: `general`.
    """
    instruction_text: builtins.str
    """The text-based instruction for the conversation."""
    @property
    def generation_options(self) -> yandex.cloud.ai.llm.v1alpha.llm_pb2.GenerationOptions:
        """Configuration options for text generation."""

    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.llm.v1alpha.llm_pb2.Message]:
        """A list of messages in the conversation."""

    def __init__(
        self,
        *,
        model: builtins.str = ...,
        generation_options: yandex.cloud.ai.llm.v1alpha.llm_pb2.GenerationOptions | None = ...,
        instruction_text: builtins.str = ...,
        messages: collections.abc.Iterable[yandex.cloud.ai.llm.v1alpha.llm_pb2.Message] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Instruction", b"Instruction", "generation_options", b"generation_options", "instruction_text", b"instruction_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Instruction", b"Instruction", "generation_options", b"generation_options", "instruction_text", b"instruction_text", "messages", b"messages", "model", b"model"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Instruction", b"Instruction"]) -> typing.Literal["instruction_text"] | None: ...

global___ChatRequest = ChatRequest

@typing.final
class ChatResponse(google.protobuf.message.Message):
    """Contains a model-generated response for a chat query."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    NUM_TOKENS_FIELD_NUMBER: builtins.int
    num_tokens: builtins.int
    """Total number of tokens used in both the chat request and chat response."""
    @property
    def message(self) -> yandex.cloud.ai.llm.v1alpha.llm_pb2.Message:
        """The assistant's message in the chat conversation."""

    def __init__(
        self,
        *,
        message: yandex.cloud.ai.llm.v1alpha.llm_pb2.Message | None = ...,
        num_tokens: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "num_tokens", b"num_tokens"]) -> None: ...

global___ChatResponse = ChatResponse

@typing.final
class TokenizeRequest(google.protobuf.message.Message):
    """Request to tokenize input text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    model: builtins.str
    """The name or identifier of the model to be used for tokenization.
    Possible values for now: `general`, `general:embedding`.
    """
    text: builtins.str
    """The input text to tokenize."""
    def __init__(
        self,
        *,
        model: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model", b"model", "text", b"text"]) -> None: ...

global___TokenizeRequest = TokenizeRequest

@typing.final
class TokenizeResponse(google.protobuf.message.Message):
    """Tokenization response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_FIELD_NUMBER: builtins.int
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.llm.v1alpha.llm_pb2.Token]:
        """A list of tokens obtained from tokenization."""

    def __init__(
        self,
        *,
        tokens: collections.abc.Iterable[yandex.cloud.ai.llm.v1alpha.llm_pb2.Token] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["tokens", b"tokens"]) -> None: ...

global___TokenizeResponse = TokenizeResponse

@typing.final
class EmbeddingRequest(google.protobuf.message.Message):
    """Represents a request to obtain embeddings for text data."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _EmbeddingType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EmbeddingTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[EmbeddingRequest._EmbeddingType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        EMBEDDING_TYPE_UNSPECIFIED: EmbeddingRequest._EmbeddingType.ValueType  # 0
        """Unspecified embedding type."""
        EMBEDDING_TYPE_QUERY: EmbeddingRequest._EmbeddingType.ValueType  # 1
        """Embedding for a query. Use this when you have a short query or search term
        that you want to obtain an embedding for. Query embeddings are typically
        used in information retrieval and search applications.
        """
        EMBEDDING_TYPE_DOCUMENT: EmbeddingRequest._EmbeddingType.ValueType  # 2
        """Embedding for a document. Use this when you have a longer document or a piece
        of text that you want to obtain an embedding for. Document embeddings are often
        used in natural language understanding and document similarity tasks.
        """

    class EmbeddingType(_EmbeddingType, metaclass=_EmbeddingTypeEnumTypeWrapper):
        """Enum to specify the type of embedding to be generated."""

    EMBEDDING_TYPE_UNSPECIFIED: EmbeddingRequest.EmbeddingType.ValueType  # 0
    """Unspecified embedding type."""
    EMBEDDING_TYPE_QUERY: EmbeddingRequest.EmbeddingType.ValueType  # 1
    """Embedding for a query. Use this when you have a short query or search term
    that you want to obtain an embedding for. Query embeddings are typically
    used in information retrieval and search applications.
    """
    EMBEDDING_TYPE_DOCUMENT: EmbeddingRequest.EmbeddingType.ValueType  # 2
    """Embedding for a document. Use this when you have a longer document or a piece
    of text that you want to obtain an embedding for. Document embeddings are often
    used in natural language understanding and document similarity tasks.
    """

    EMBEDDING_TYPE_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    embedding_type: global___EmbeddingRequest.EmbeddingType.ValueType
    """The type of embedding to be generated."""
    model: builtins.str
    """The name or identifier of the model to be used for embedding. Possible value for now: `general:embedding`."""
    text: builtins.str
    """The input text for which the embedding is requested."""
    def __init__(
        self,
        *,
        embedding_type: global___EmbeddingRequest.EmbeddingType.ValueType = ...,
        model: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["embedding_type", b"embedding_type", "model", b"model", "text", b"text"]) -> None: ...

global___EmbeddingRequest = EmbeddingRequest

@typing.final
class EmbeddingResponse(google.protobuf.message.Message):
    """Represents a response containing embeddings for input text data."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMBEDDING_FIELD_NUMBER: builtins.int
    NUM_TOKENS_FIELD_NUMBER: builtins.int
    num_tokens: builtins.int
    """The number of tokens in the input text."""
    @property
    def embedding(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]:
        """A repeated list of double values representing the embedding."""

    def __init__(
        self,
        *,
        embedding: collections.abc.Iterable[builtins.float] | None = ...,
        num_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["embedding", b"embedding", "num_tokens", b"num_tokens"]) -> None: ...

global___EmbeddingResponse = EmbeddingResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/marketplace/licensemanager/v1/instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.marketplace.licensemanager.v1 import lock_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2
from yandex.cloud.marketplace.licensemanager.v1 import template_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/marketplace/licensemanager/v1/instance.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x35yandex/cloud/marketplace/licensemanager/v1/lock.proto\x1a\x39yandex/cloud/marketplace/licensemanager/v1/template.proto\"\x94\x05\n\x08Instance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x13\n\x0btemplate_id\x18\x04 \x01(\t\x12\x1b\n\x13template_version_id\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0e \x01(\t\x12.\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x05state\x18\x0b \x01(\x0e\x32:.yandex.cloud.marketplace.licensemanager.v1.Instance.State\x12?\n\x05locks\x18\x0c \x03(\x0b\x32\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\x12N\n\x10license_template\x18\r \x01(\x0b\x32\x34.yandex.cloud.marketplace.licensemanager.v1.Template\"p\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\r\n\tCANCELLED\x10\x03\x12\x0b\n\x07\x45XPIRED\x10\x04\x12\x0e\n\nDEPRECATED\x10\x05\x12\x0b\n\x07\x44\x45LETED\x10\x06J\x04\x08\x06\x10\x07\x42\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.v1.instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager'
  _globals['_INSTANCE']._serialized_start=253
  _globals['_INSTANCE']._serialized_end=913
  _globals['_INSTANCE_STATE']._serialized_start=795
  _globals['_INSTANCE_STATE']._serialized_end=907
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.user_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class UserServiceStub:
    """A set of methods for managing Organization users."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListMembers: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersRequest,
        yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersResponse,
    ]
    """List organization active members."""

    DeleteMembership: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.user_service_pb2.DeleteMembershipRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete user membership."""

class UserServiceAsyncStub:
    """A set of methods for managing Organization users."""

    ListMembers: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersRequest,
        yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersResponse,
    ]
    """List organization active members."""

    DeleteMembership: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.user_service_pb2.DeleteMembershipRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete user membership."""

class UserServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Organization users."""

    @abc.abstractmethod
    def ListMembers(
        self,
        request: yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.user_service_pb2.ListMembersResponse]]:
        """List organization active members."""

    @abc.abstractmethod
    def DeleteMembership(
        self,
        request: yandex.cloud.organizationmanager.v1.user_service_pb2.DeleteMembershipRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete user membership."""

def add_UserServiceServicer_to_server(servicer: UserServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PXFConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_TIMEOUT_FIELD_NUMBER: builtins.int
    UPLOAD_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_THREADS_FIELD_NUMBER: builtins.int
    POOL_ALLOW_CORE_THREAD_TIMEOUT_FIELD_NUMBER: builtins.int
    POOL_CORE_SIZE_FIELD_NUMBER: builtins.int
    POOL_QUEUE_CAPACITY_FIELD_NUMBER: builtins.int
    POOL_MAX_SIZE_FIELD_NUMBER: builtins.int
    XMX_FIELD_NUMBER: builtins.int
    XMS_FIELD_NUMBER: builtins.int
    @property
    def connection_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Timeout for connection to the Apache Tomcat® server when making read requests.

        Specify values in seconds.
        """

    @property
    def upload_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Timeout for connection to the Apache Tomcat® server when making write requests.

        Specify the values in seconds.
        """

    @property
    def max_threads(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of the Apache Tomcat® threads.

        To prevent situations when requests get stuck or fail due to running out of memory or malfunctioning of the Java garbage collector, specify the number of the Apache Tomcat® threads. Learn more about adjusting the number of threads in the [VMware Greenplum® Platform Extension Framework](https://docs.vmware.com/en/VMware-Greenplum-Platform-Extension-Framework/6.9/greenplum-platform-extension-framework/cfg_mem.html) documentation.
        """

    @property
    def pool_allow_core_thread_timeout(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether the timeout for core streaming threads is permitted."""

    @property
    def pool_core_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Number of core streaming threads per pool."""

    @property
    def pool_queue_capacity(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of requests you can add to a pool queue for core streaming threads.

        If `0`, no pool queue is generated.
        """

    @property
    def pool_max_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum allowed number of core streaming threads."""

    @property
    def xmx(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Initial size, in megabytes, of the JVM heap for the PXF daemon."""

    @property
    def xms(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum size, in megabytes, of the JVM heap for the PXF daemon."""

    def __init__(
        self,
        *,
        connection_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        upload_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_threads: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_allow_core_thread_timeout: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pool_core_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_queue_capacity: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_max_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        xmx: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        xms: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["connection_timeout", b"connection_timeout", "max_threads", b"max_threads", "pool_allow_core_thread_timeout", b"pool_allow_core_thread_timeout", "pool_core_size", b"pool_core_size", "pool_max_size", b"pool_max_size", "pool_queue_capacity", b"pool_queue_capacity", "upload_timeout", b"upload_timeout", "xms", b"xms", "xmx", b"xmx"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_timeout", b"connection_timeout", "max_threads", b"max_threads", "pool_allow_core_thread_timeout", b"pool_allow_core_thread_timeout", "pool_core_size", b"pool_core_size", "pool_max_size", b"pool_max_size", "pool_queue_capacity", b"pool_queue_capacity", "upload_timeout", b"upload_timeout", "xms", b"xms", "xmx", b"xmx"]) -> None: ...

global___PXFConfig = PXFConfig

@typing.final
class PXFConfigSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___PXFConfig: ...
    @property
    def user_config(self) -> global___PXFConfig:
        """User-defined settings."""

    @property
    def default_config(self) -> global___PXFConfig:
        """Default configuration."""

    def __init__(
        self,
        *,
        effective_config: global___PXFConfig | None = ...,
        user_config: global___PXFConfig | None = ...,
        default_config: global___PXFConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___PXFConfigSet = PXFConfigSet

@typing.final
class PXFDatasourceS3(google.protobuf.message.Message):
    """Datasources API"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_FIELD_NUMBER: builtins.int
    SECRET_KEY_FIELD_NUMBER: builtins.int
    FAST_UPLOAD_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    access_key: builtins.str
    """Public key to access S3 storage."""
    secret_key: builtins.str
    """Secret key to access S3 storage."""
    endpoint: builtins.str
    """S3 storage address. The default value is `storage.yandexcloud.net` used for Yandex Object Storage."""
    @property
    def fast_upload(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Manages a fast upload of big files to S3 storage. In case of the `false` value, the PXF generates files on disk before sending them to the S3 storage. In case of the `true` value, the PXF generates files in RAM (the PXF writes to disc only if there is not enough RAM).

        The fast upload is enabled by default.
        """

    def __init__(
        self,
        *,
        access_key: builtins.str = ...,
        secret_key: builtins.str = ...,
        fast_upload: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        endpoint: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["fast_upload", b"fast_upload"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_key", b"access_key", "endpoint", b"endpoint", "fast_upload", b"fast_upload", "secret_key", b"secret_key"]) -> None: ...

global___PXFDatasourceS3 = PXFDatasourceS3

@typing.final
class PXFDatasourceJDBC(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRIVER_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    STATEMENT_BATCH_SIZE_FIELD_NUMBER: builtins.int
    STATEMENT_FETCH_SIZE_FIELD_NUMBER: builtins.int
    STATEMENT_QUERY_TIMEOUT_FIELD_NUMBER: builtins.int
    POOL_ENABLED_FIELD_NUMBER: builtins.int
    POOL_MAXIMUM_SIZE_FIELD_NUMBER: builtins.int
    POOL_CONNECTION_TIMEOUT_FIELD_NUMBER: builtins.int
    POOL_IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    POOL_MINIMUM_IDLE_FIELD_NUMBER: builtins.int
    driver: builtins.str
    """JDBC driver class in Java. The possible values are the following:

    * `com.simba.athena.jdbc.Driver`
    * `com.clickhouse.jdbc.ClickHouseDriver`
    * `com.ibm.as400.access.AS400JDBCDriver`
    * `com.microsoft.sqlserver.jdbc.SQLServerDriver`
    * `com.mysql.cj.jdbc.Driver`
    * `org.postgresql.Driver`
    * `oracle.jdbc.driver.OracleDriver`
    * `net.snowflake.client.jdbc.SnowflakeDriver`
    * `io.trino.jdbc.TrinoDriver`
    """
    url: builtins.str
    """URL that the JDBC driver uses to connect to the database. Examples:

    * `jdbc:mysql://mysqlhost:3306/testdb`: Local MySQL DB.
    * `jdbc:postgresql://c-<cluster_id>.rw.mdb.yandexcloud.net:6432/db1`: Managed Service for PostgreSQL cluster. The address contains the special FQDN of the cluster's master.
    * `jdbc:oracle:thin:@host.example:1521:orcl`: Oracle DB.
    """
    user: builtins.str
    """Username of the DB owner."""
    password: builtins.str
    """Password of the DB owner."""
    @property
    def statement_batch_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Number of rows to read in an external table, in a batch.

        The default value is `100`.
        """

    @property
    def statement_fetch_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Number of rows to fetch (buffer) when reading from an external table.

        The default value is `1000`.
        """

    @property
    def statement_query_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Amount of time (in seconds) the JDBC driver waits for a statement to run. This timeout applies to statements created for both read and write operations.

        The default value is `60`.
        """

    @property
    def pool_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether JDBC connection pooling is used in a server configuration. By default, it is used."""

    @property
    def pool_maximum_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of connections to the DB backend.

        The default value is `5`.
        """

    @property
    def pool_connection_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum time, in milliseconds, to wait for a connection from the pool.

        The default value is `30000`.
        """

    @property
    def pool_idle_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum amount of time, in milliseconds, after which an inactive connection is considered idle.

        The default value is `30000`.
        """

    @property
    def pool_minimum_idle(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Minimum number of idle connections maintained in the connection pool.

        The default value is `0`.
        """

    def __init__(
        self,
        *,
        driver: builtins.str = ...,
        url: builtins.str = ...,
        user: builtins.str = ...,
        password: builtins.str = ...,
        statement_batch_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        statement_fetch_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        statement_query_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        pool_maximum_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_connection_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_idle_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        pool_minimum_idle: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pool_connection_timeout", b"pool_connection_timeout", "pool_enabled", b"pool_enabled", "pool_idle_timeout", b"pool_idle_timeout", "pool_maximum_size", b"pool_maximum_size", "pool_minimum_idle", b"pool_minimum_idle", "statement_batch_size", b"statement_batch_size", "statement_fetch_size", b"statement_fetch_size", "statement_query_timeout", b"statement_query_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["driver", b"driver", "password", b"password", "pool_connection_timeout", b"pool_connection_timeout", "pool_enabled", b"pool_enabled", "pool_idle_timeout", b"pool_idle_timeout", "pool_maximum_size", b"pool_maximum_size", "pool_minimum_idle", b"pool_minimum_idle", "statement_batch_size", b"statement_batch_size", "statement_fetch_size", b"statement_fetch_size", "statement_query_timeout", b"statement_query_timeout", "url", b"url", "user", b"user"]) -> None: ...

global___PXFDatasourceJDBC = PXFDatasourceJDBC

@typing.final
class PXFDatasourceCore(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_FS_FIELD_NUMBER: builtins.int
    SECURITY_AUTH_TO_LOCAL_FIELD_NUMBER: builtins.int
    default_fs: builtins.str
    """URI whose scheme and authority determine the file system implementation."""
    security_auth_to_local: builtins.str
    """Rules for mapping Kerberos principals to operating system user accounts."""
    def __init__(
        self,
        *,
        default_fs: builtins.str = ...,
        security_auth_to_local: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default_fs", b"default_fs", "security_auth_to_local", b"security_auth_to_local"]) -> None: ...

global___PXFDatasourceCore = PXFDatasourceCore

@typing.final
class PXFDatasourceKerberos(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    REALM_FIELD_NUMBER: builtins.int
    KDC_SERVERS_FIELD_NUMBER: builtins.int
    ADMIN_SERVER_FIELD_NUMBER: builtins.int
    DEFAULT_DOMAIN_FIELD_NUMBER: builtins.int
    KEYTAB_BASE64_FIELD_NUMBER: builtins.int
    primary: builtins.str
    """Host of the primary KDC server (Key Distribution Center)."""
    realm: builtins.str
    """Kerberos realm for a Greenplum® DB."""
    admin_server: builtins.str
    """Administration server host. Usually, this is the primary Kerberos server."""
    default_domain: builtins.str
    """Domain that is used for the host name extension. Applicable when Kerberos 4 service members become Kerberos 5 service members (for example, when rcmd.hostname is replaced with host/hostname.domain)."""
    keytab_base64: builtins.str
    """Base64 encoded contents of the keytab file."""
    @property
    def enable(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether the Kerberos authentication server is used. By default, it is not used."""

    @property
    def kdc_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """KDC server hosts."""

    def __init__(
        self,
        *,
        enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        primary: builtins.str = ...,
        realm: builtins.str = ...,
        kdc_servers: collections.abc.Iterable[builtins.str] | None = ...,
        admin_server: builtins.str = ...,
        default_domain: builtins.str = ...,
        keytab_base64: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enable", b"enable"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admin_server", b"admin_server", "default_domain", b"default_domain", "enable", b"enable", "kdc_servers", b"kdc_servers", "keytab_base64", b"keytab_base64", "primary", b"primary", "realm", b"realm"]) -> None: ...

global___PXFDatasourceKerberos = PXFDatasourceKerberos

@typing.final
class PXFDatasourceHDFSDfsNamenode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RPC_ADDRESS_FIELD_NUMBER: builtins.int
    SERVICE_RPC_ADDRESS_FIELD_NUMBER: builtins.int
    HTTP_ADDRESS_FIELD_NUMBER: builtins.int
    HTTPS_ADDRESS_FIELD_NUMBER: builtins.int
    rpc_address: builtins.str
    service_rpc_address: builtins.str
    http_address: builtins.str
    https_address: builtins.str
    def __init__(
        self,
        *,
        rpc_address: builtins.str = ...,
        service_rpc_address: builtins.str = ...,
        http_address: builtins.str = ...,
        https_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["http_address", b"http_address", "https_address", b"https_address", "rpc_address", b"rpc_address", "service_rpc_address", b"service_rpc_address"]) -> None: ...

global___PXFDatasourceHDFSDfsNamenode = PXFDatasourceHDFSDfsNamenode

@typing.final
class PXFDatasourceHDFSDfs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NamenodesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___PXFDatasourceHDFSDfsNamenode: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___PXFDatasourceHDFSDfsNamenode | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    HA_AUTOMATIC_FAILOVER_ENABLED_FIELD_NUMBER: builtins.int
    BLOCK_ACCESS_TOKEN_ENABLED_FIELD_NUMBER: builtins.int
    USE_DATANODE_HOSTNAME_FIELD_NUMBER: builtins.int
    NAMENODES_FIELD_NUMBER: builtins.int
    NAMESERVICES_FIELD_NUMBER: builtins.int
    nameservices: builtins.str
    """Corresponds well-known HDFS client setting "dfs.nameservices" for this datasource"""
    @property
    def ha_automatic_failover_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether automatic failover is enabled for the high availability of the file system.

        The automatic failover is enabled by default.
        """

    @property
    def block_access_token_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """If `true`, access tokens are used as capabilities for accessing datanodes. If `false`, no access tokens are checked on accessing datanodes.

        The check of access tokens is enabled by default.
        """

    @property
    def use_datanode_hostname(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether the datanode hostname is used when connecting to datanodes."""

    @property
    def namenodes(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___PXFDatasourceHDFSDfsNamenode]:
        """List of HDFS service logical names.

        Specify them separated by commas. The names can be arbitrary.
        """

    def __init__(
        self,
        *,
        ha_automatic_failover_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        block_access_token_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        use_datanode_hostname: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        namenodes: collections.abc.Mapping[builtins.str, global___PXFDatasourceHDFSDfsNamenode] | None = ...,
        nameservices: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["block_access_token_enabled", b"block_access_token_enabled", "ha_automatic_failover_enabled", b"ha_automatic_failover_enabled", "use_datanode_hostname", b"use_datanode_hostname"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["block_access_token_enabled", b"block_access_token_enabled", "ha_automatic_failover_enabled", b"ha_automatic_failover_enabled", "namenodes", b"namenodes", "nameservices", b"nameservices", "use_datanode_hostname", b"use_datanode_hostname"]) -> None: ...

global___PXFDatasourceHDFSDfs = PXFDatasourceHDFSDfs

@typing.final
class PXFDatasourceHDFSYarnHaRm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCEMANAGER_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_SCHEDULER_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_RESOURCE_TRACKER_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_ADMIN_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_WEBAPP_ADDRESS_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_WEBAPP_HTTPS_ADDRESS_FIELD_NUMBER: builtins.int
    resourcemanager_address: builtins.str
    resourcemanager_scheduler_address: builtins.str
    resourcemanager_resource_tracker_address: builtins.str
    resourcemanager_admin_address: builtins.str
    resourcemanager_webapp_address: builtins.str
    resourcemanager_webapp_https_address: builtins.str
    def __init__(
        self,
        *,
        resourcemanager_address: builtins.str = ...,
        resourcemanager_scheduler_address: builtins.str = ...,
        resourcemanager_resource_tracker_address: builtins.str = ...,
        resourcemanager_admin_address: builtins.str = ...,
        resourcemanager_webapp_address: builtins.str = ...,
        resourcemanager_webapp_https_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["resourcemanager_address", b"resourcemanager_address", "resourcemanager_admin_address", b"resourcemanager_admin_address", "resourcemanager_resource_tracker_address", b"resourcemanager_resource_tracker_address", "resourcemanager_scheduler_address", b"resourcemanager_scheduler_address", "resourcemanager_webapp_address", b"resourcemanager_webapp_address", "resourcemanager_webapp_https_address", b"resourcemanager_webapp_https_address"]) -> None: ...

global___PXFDatasourceHDFSYarnHaRm = PXFDatasourceHDFSYarnHaRm

@typing.final
class PXFDatasourceHDFSYarn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HaRmEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___PXFDatasourceHDFSYarnHaRm: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___PXFDatasourceHDFSYarnHaRm | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCEMANAGER_HA_ENABLED_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_HA_AUTO_FAILOVER_ENABLED_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_HA_AUTO_FAILOVER_EMBEDDED_FIELD_NUMBER: builtins.int
    RESOURCEMANAGER_CLUSTER_ID_FIELD_NUMBER: builtins.int
    HA_RM_FIELD_NUMBER: builtins.int
    resourcemanager_cluster_id: builtins.str
    """Cluster ID. Specify it, so the ResourceManager service does not become active for a different cluster."""
    @property
    def resourcemanager_ha_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether high availability is enabled for YARN's ResourceManager services.

        The high availability is enabled by default.
        """

    @property
    def resourcemanager_ha_auto_failover_enabled(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether another ResourceManager should automatically become active when the active ResourceManager has failed and does not respond.

        The switch of ResourceManagers is enabled by default if the high availability is enabled.
        """

    @property
    def resourcemanager_ha_auto_failover_embedded(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Determines whether the embedded ActiveStandbyElector method should be used for the election of the active ResourceManager. If the current active ResourceManager has failed and does not respond, the ActiveStandbyElector method makes another ResourceManager active which then takes over."""

    @property
    def ha_rm(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___PXFDatasourceHDFSYarnHaRm]:
        """Highly available ResourceManager service."""

    def __init__(
        self,
        *,
        resourcemanager_ha_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        resourcemanager_ha_auto_failover_enabled: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        resourcemanager_ha_auto_failover_embedded: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        resourcemanager_cluster_id: builtins.str = ...,
        ha_rm: collections.abc.Mapping[builtins.str, global___PXFDatasourceHDFSYarnHaRm] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resourcemanager_ha_auto_failover_embedded", b"resourcemanager_ha_auto_failover_embedded", "resourcemanager_ha_auto_failover_enabled", b"resourcemanager_ha_auto_failover_enabled", "resourcemanager_ha_enabled", b"resourcemanager_ha_enabled"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ha_rm", b"ha_rm", "resourcemanager_cluster_id", b"resourcemanager_cluster_id", "resourcemanager_ha_auto_failover_embedded", b"resourcemanager_ha_auto_failover_embedded", "resourcemanager_ha_auto_failover_enabled", b"resourcemanager_ha_auto_failover_enabled", "resourcemanager_ha_enabled", b"resourcemanager_ha_enabled"]) -> None: ...

global___PXFDatasourceHDFSYarn = PXFDatasourceHDFSYarn

@typing.final
class PXFDatasourceHDFS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_FIELD_NUMBER: builtins.int
    KERBEROS_FIELD_NUMBER: builtins.int
    USER_IMPERSONATION_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    SASL_CONNECTION_RETRIES_FIELD_NUMBER: builtins.int
    ZK_HOSTS_FIELD_NUMBER: builtins.int
    DFS_FIELD_NUMBER: builtins.int
    YARN_FIELD_NUMBER: builtins.int
    username: builtins.str
    """Login username for the remote file storage or DBMS if authentication on behalf of the Greenplum® user is enabled."""
    @property
    def core(self) -> global___PXFDatasourceCore:
        """Settings of the file system and security rules."""

    @property
    def kerberos(self) -> global___PXFDatasourceKerberos:
        """Settings of the Kerberos network authentication protocol."""

    @property
    def user_impersonation(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables authentication on behalf of the Greenplum® user when connecting to the remote file storage or DBMS.

        The authentication is disabled by default.
        """

    @property
    def sasl_connection_retries(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of times that PXF retries a SASL connection request after a refused connection returns a `GSS initiate failed` error.

        The default value is `5`.
        """

    @property
    def zk_hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ZooKeeper server hosts.

        Specify values in the `<address>:<port>` format.
        """

    @property
    def dfs(self) -> global___PXFDatasourceHDFSDfs:
        """Settings of the distributed file system."""

    @property
    def yarn(self) -> global___PXFDatasourceHDFSYarn:
        """Settings of the ResourceManager service that is responsible for tracking resources in a cluster and scheduling applications (e.g., MapReduce jobs)."""

    def __init__(
        self,
        *,
        core: global___PXFDatasourceCore | None = ...,
        kerberos: global___PXFDatasourceKerberos | None = ...,
        user_impersonation: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        username: builtins.str = ...,
        sasl_connection_retries: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        zk_hosts: collections.abc.Iterable[builtins.str] | None = ...,
        dfs: global___PXFDatasourceHDFSDfs | None = ...,
        yarn: global___PXFDatasourceHDFSYarn | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["core", b"core", "dfs", b"dfs", "kerberos", b"kerberos", "sasl_connection_retries", b"sasl_connection_retries", "user_impersonation", b"user_impersonation", "yarn", b"yarn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["core", b"core", "dfs", b"dfs", "kerberos", b"kerberos", "sasl_connection_retries", b"sasl_connection_retries", "user_impersonation", b"user_impersonation", "username", b"username", "yarn", b"yarn", "zk_hosts", b"zk_hosts"]) -> None: ...

global___PXFDatasourceHDFS = PXFDatasourceHDFS

@typing.final
class PXFDatasourceHive(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_FIELD_NUMBER: builtins.int
    KERBEROS_FIELD_NUMBER: builtins.int
    USER_IMPERSONATION_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    SASL_CONNECTION_RETRIES_FIELD_NUMBER: builtins.int
    ZK_HOSTS_FIELD_NUMBER: builtins.int
    PPD_FIELD_NUMBER: builtins.int
    METASTORE_URIS_FIELD_NUMBER: builtins.int
    METASTORE_KERBEROS_PRINCIPAL_FIELD_NUMBER: builtins.int
    AUTH_KERBEROS_PRINCIPAL_FIELD_NUMBER: builtins.int
    username: builtins.str
    """Login username for the remote file storage or DBMS if authentication on behalf of the Greenplum® user is enabled."""
    metastore_kerberos_principal: builtins.str
    """Service principal for the Metastore Thrift server."""
    auth_kerberos_principal: builtins.str
    """Kerberos server principal."""
    @property
    def core(self) -> global___PXFDatasourceCore:
        """Settings of the file system and security rules."""

    @property
    def kerberos(self) -> global___PXFDatasourceKerberos:
        """Settings of the Kerberos network authentication protocol."""

    @property
    def user_impersonation(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Enables authentication on behalf of the Greenplum® user when connecting to the remote file storage or DBMS.

        The authentication is disabled by default.
        """

    @property
    def sasl_connection_retries(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of times that PXF retries a SASL connection request after a refused connection returns a `GSS initiate failed` error.

        The default value is `5`.
        """

    @property
    def zk_hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """ZooKeeper server hosts.

        Specify values in the `<address>:<port>` format.
        """

    @property
    def ppd(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies if predicate pushdown is enabled for queries on external tables.

        The predicate pushdown is enabled by default.
        """

    @property
    def metastore_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of URIs separated by commas. To request metadata, the remote DBMS connects to Metastore by one of these URIs."""

    def __init__(
        self,
        *,
        core: global___PXFDatasourceCore | None = ...,
        kerberos: global___PXFDatasourceKerberos | None = ...,
        user_impersonation: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        username: builtins.str = ...,
        sasl_connection_retries: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        zk_hosts: collections.abc.Iterable[builtins.str] | None = ...,
        ppd: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        metastore_uris: collections.abc.Iterable[builtins.str] | None = ...,
        metastore_kerberos_principal: builtins.str = ...,
        auth_kerberos_principal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["core", b"core", "kerberos", b"kerberos", "ppd", b"ppd", "sasl_connection_retries", b"sasl_connection_retries", "user_impersonation", b"user_impersonation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["auth_kerberos_principal", b"auth_kerberos_principal", "core", b"core", "kerberos", b"kerberos", "metastore_kerberos_principal", b"metastore_kerberos_principal", "metastore_uris", b"metastore_uris", "ppd", b"ppd", "sasl_connection_retries", b"sasl_connection_retries", "user_impersonation", b"user_impersonation", "username", b"username", "zk_hosts", b"zk_hosts"]) -> None: ...

global___PXFDatasourceHive = PXFDatasourceHive

@typing.final
class PXFDatasource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    JDBC_FIELD_NUMBER: builtins.int
    HDFS_FIELD_NUMBER: builtins.int
    HIVE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Data source name."""
    @property
    def s3(self) -> global___PXFDatasourceS3:
        """Settings of an external S3 data source."""

    @property
    def jdbc(self) -> global___PXFDatasourceJDBC:
        """Settings of an external JDBC data source."""

    @property
    def hdfs(self) -> global___PXFDatasourceHDFS:
        """Settings of an external HDFS data source."""

    @property
    def hive(self) -> global___PXFDatasourceHive:
        """Settings of an external Hive data source."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        s3: global___PXFDatasourceS3 | None = ...,
        jdbc: global___PXFDatasourceJDBC | None = ...,
        hdfs: global___PXFDatasourceHDFS | None = ...,
        hive: global___PXFDatasourceHive | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hdfs", b"hdfs", "hive", b"hive", "jdbc", b"jdbc", "s3", b"s3", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["hdfs", b"hdfs", "hive", b"hive", "jdbc", b"jdbc", "name", b"name", "s3", b"s3", "settings", b"settings"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["settings", b"settings"]) -> typing.Literal["s3", "jdbc", "hdfs", "hive"] | None: ...

global___PXFDatasource = PXFDatasource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cloudrouter/v1/routing_instance.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/cloudrouter/v1/routing_instance.proto\x12\x1byandex.cloud.cloudrouter.v1\"\x91\x08\n\x0fRoutingInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x11\n\tregion_id\x18\x06 \x01(\t\x12\x46\n\x08vpc_info\x18\x07 \x03(\x0b\x32\x34.yandex.cloud.cloudrouter.v1.RoutingInstance.VpcInfo\x12j\n\x1b\x63ic_private_connection_info\x18\x08 \x03(\x0b\x32\x45.yandex.cloud.cloudrouter.v1.RoutingInstance.CicPrivateConnectionInfo\x12\x43\n\x06status\x18\t \x01(\x0e\x32\x33.yandex.cloud.cloudrouter.v1.RoutingInstance.Status\x12H\n\x06labels\x18\x18 \x03(\x0b\x32\x38.yandex.cloud.cloudrouter.v1.RoutingInstance.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a=\n\x18\x43icPrivateConnectionInfo\x12!\n\x19\x63ic_private_connection_id\x18\x01 \x01(\t\x1ak\n\x07VpcInfo\x12\x16\n\x0evpc_network_id\x18\x01 \x01(\t\x12H\n\x08\x61z_infos\x18\x02 \x03(\x0b\x32\x36.yandex.cloud.cloudrouter.v1.RoutingInstance.VpcAzInfo\x1a\xb9\x01\n\tVpcAzInfo\x12O\n\x0bmanual_info\x18\x02 \x01(\x0b\x32:.yandex.cloud.cloudrouter.v1.RoutingInstance.VpcManualInfo\x12U\n\x0e\x61utomatic_info\x18\x03 \x01(\x0b\x32=.yandex.cloud.cloudrouter.v1.RoutingInstance.VpcAutomaticInfoJ\x04\x08\x01\x10\x02\x1a\x36\n\rVpcManualInfo\x12\r\n\x05\x61z_id\x18\x01 \x01(\t\x12\x10\n\x08prefixes\x18\x05 \x03(\tJ\x04\x08\x02\x10\x05\x1a\x33\n\x10VpcAutomaticInfo\x12\r\n\x05\x61z_id\x18\x01 \x01(\t\x12\x10\n\x08prefixes\x18\x02 \x03(\t\"V\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08UPDATING\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\n\x10\x18\x42n\n\x1fyandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudrouter.v1.routing_instance_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.cloudrouter.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudrouter/v1;cloudrouter'
  _ROUTINGINSTANCE_LABELSENTRY._options = None
  _ROUTINGINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _globals['_ROUTINGINSTANCE']._serialized_start=84
  _globals['_ROUTINGINSTANCE']._serialized_end=1125
  _globals['_ROUTINGINSTANCE_LABELSENTRY']._serialized_start=511
  _globals['_ROUTINGINSTANCE_LABELSENTRY']._serialized_end=556
  _globals['_ROUTINGINSTANCE_CICPRIVATECONNECTIONINFO']._serialized_start=558
  _globals['_ROUTINGINSTANCE_CICPRIVATECONNECTIONINFO']._serialized_end=619
  _globals['_ROUTINGINSTANCE_VPCINFO']._serialized_start=621
  _globals['_ROUTINGINSTANCE_VPCINFO']._serialized_end=728
  _globals['_ROUTINGINSTANCE_VPCAZINFO']._serialized_start=731
  _globals['_ROUTINGINSTANCE_VPCAZINFO']._serialized_end=916
  _globals['_ROUTINGINSTANCE_VPCMANUALINFO']._serialized_start=918
  _globals['_ROUTINGINSTANCE_VPCMANUALINFO']._serialized_end=972
  _globals['_ROUTINGINSTANCE_VPCAUTOMATICINFO']._serialized_start=974
  _globals['_ROUTINGINSTANCE_VPCAUTOMATICINFO']._serialized_end=1025
  _globals['_ROUTINGINSTANCE_STATUS']._serialized_start=1027
  _globals['_ROUTINGINSTANCE_STATUS']._serialized_end=1113
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.compute.v1.hardware_generation_pb2
import yandex.cloud.compute.v1.snapshot_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSnapshotRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the Snapshot resource to return.
    To get the snapshot ID, use a [SnapshotService.List] request.
    """
    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_id", b"snapshot_id"]) -> None: ...

global___GetSnapshotRequest = GetSnapshotRequest

@typing.final
class ListSnapshotsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list snapshots in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListSnapshotsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSnapshotsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    The default sorting order is ascending
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSnapshotsRequest = ListSnapshotsRequest

@typing.final
class ListSnapshotsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSnapshotsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListSnapshotsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def snapshots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.snapshot_pb2.Snapshot]:
        """List of snapshots."""

    def __init__(
        self,
        *,
        snapshots: collections.abc.Iterable[yandex.cloud.compute.v1.snapshot_pb2.Snapshot] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "snapshots", b"snapshots"]) -> None: ...

global___ListSnapshotsResponse = ListSnapshotsResponse

@typing.final
class CreateSnapshotRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    DISK_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    HARDWARE_GENERATION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a snapshot in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    disk_id: builtins.str
    """ID of the disk to create the snapshot from.
    To get the disk ID use a [yandex.cloud.compute.v1.DiskService.List] request.
    """
    name: builtins.str
    """Name of the snapshot."""
    description: builtins.str
    """Description of the snapshot."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def hardware_generation(self) -> yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration:
        """Specify the overrides to hardware_generation of a source disk, image or snapshot,
        or to the default values if the source does not define it.
        """

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        disk_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        hardware_generation: yandex.cloud.compute.v1.hardware_generation_pb2.HardwareGeneration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["hardware_generation", b"hardware_generation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "disk_id", b"disk_id", "folder_id", b"folder_id", "hardware_generation", b"hardware_generation", "labels", b"labels", "name", b"name"]) -> None: ...

global___CreateSnapshotRequest = CreateSnapshotRequest

@typing.final
class CreateSnapshotMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    DISK_ID_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the snapshot that is being created."""
    disk_id: builtins.str
    """ID of the source disk used to create this snapshot."""
    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
        disk_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_id", b"disk_id", "snapshot_id", b"snapshot_id"]) -> None: ...

global___CreateSnapshotMetadata = CreateSnapshotMetadata

@typing.final
class UpdateSnapshotRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the Snapshot resource to update.
    To get the snapshot ID use a [SnapshotService.List] request.
    """
    name: builtins.str
    """Name of the snapshot."""
    description: builtins.str
    """Description of the snapshot."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Snapshot resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "snapshot_id", b"snapshot_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateSnapshotRequest = UpdateSnapshotRequest

@typing.final
class UpdateSnapshotMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the Snapshot resource that is being updated."""
    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_id", b"snapshot_id"]) -> None: ...

global___UpdateSnapshotMetadata = UpdateSnapshotMetadata

@typing.final
class DeleteSnapshotRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the snapshot to delete.
    To get the snapshot ID, use a [SnapshotService.List] request.
    """
    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_id", b"snapshot_id"]) -> None: ...

global___DeleteSnapshotRequest = DeleteSnapshotRequest

@typing.final
class DeleteSnapshotMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the snapshot that is being deleted."""
    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["snapshot_id", b"snapshot_id"]) -> None: ...

global___DeleteSnapshotMetadata = DeleteSnapshotMetadata

@typing.final
class ListSnapshotOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    snapshot_id: builtins.str
    """ID of the Snapshot resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListSnapshotOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListSnapshotOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        snapshot_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "snapshot_id", b"snapshot_id"]) -> None: ...

global___ListSnapshotOperationsRequest = ListSnapshotOperationsRequest

@typing.final
class ListSnapshotOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListSnapshotOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListSnapshotOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified snapshot."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSnapshotOperationsResponse = ListSnapshotOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQyandex/cloud/kms/v1/asymmetricsignature/asymmetric_signature_crypto_service.proto\x12\'yandex.cloud.kms.v1.asymmetricsignature\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\"W\n\x15\x41symmetricSignRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\x07message\x18\x02 \x01(\x0c\x42\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=32768\";\n\x16\x41symmetricSignResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"W\n\x19\x41symmetricSignHashRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\x04hash\x18\x02 \x01(\x0c\x42\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=4096\"?\n\x1a\x41symmetricSignHashResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x11\n\tsignature\x18\x02 \x01(\x0c\"=\n\x1d\x41symmetricGetPublicKeyRequest\x12\x1c\n\x06key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n\x1e\x41symmetricGetPublicKeyResponse\x12\x0e\n\x06key_id\x18\x01 \x01(\t\x12\x12\n\npublic_key\x18\x02 \x01(\t2\x98\x05\n AsymmetricSignatureCryptoService\x12\xc1\x01\n\x04Sign\x12>.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignRequest\x1a?.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/kms/v1/asymmetricSignatureKeys/{key_id}:sign:\x01*\x12\xd1\x01\n\x08SignHash\x12\x42.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashRequest\x1a\x43.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignHashResponse\"<\x82\xd3\xe4\x93\x02\x36\"1/kms/v1/asymmetricSignatureKeys/{key_id}:signHash:\x01*\x12\xdb\x01\n\x0cGetPublicKey\x12\x46.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyRequest\x1aG.yandex.cloud.kms.v1.asymmetricsignature.AsymmetricGetPublicKeyResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/kms/v1/asymmetricSignatureKeys/{key_id}/publicKeyBj\n\x17yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kmsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.kms.v1.asymmetricsignature.asymmetric_signature_crypto_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.kms.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/kms/v1/asymmetricsignature;kms'
  _ASYMMETRICSIGNREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICSIGNREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICSIGNREQUEST.fields_by_name['message']._options = None
  _ASYMMETRICSIGNREQUEST.fields_by_name['message']._serialized_options = b'\350\3071\001\212\3101\007<=32768'
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['hash']._options = None
  _ASYMMETRICSIGNHASHREQUEST.fields_by_name['hash']._serialized_options = b'\350\3071\001\212\3101\006<=4096'
  _ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._options = None
  _ASYMMETRICGETPUBLICKEYREQUEST.fields_by_name['key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['Sign']._options = None
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['Sign']._serialized_options = b'\202\323\344\223\0022\"-/kms/v1/asymmetricSignatureKeys/{key_id}:sign:\001*'
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['SignHash']._options = None
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['SignHash']._serialized_options = b'\202\323\344\223\0026\"1/kms/v1/asymmetricSignatureKeys/{key_id}:signHash:\001*'
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['GetPublicKey']._options = None
  _ASYMMETRICSIGNATURECRYPTOSERVICE.methods_by_name['GetPublicKey']._serialized_options = b'\202\323\344\223\0024\0222/kms/v1/asymmetricSignatureKeys/{key_id}/publicKey'
  _globals['_ASYMMETRICSIGNREQUEST']._serialized_start=187
  _globals['_ASYMMETRICSIGNREQUEST']._serialized_end=274
  _globals['_ASYMMETRICSIGNRESPONSE']._serialized_start=276
  _globals['_ASYMMETRICSIGNRESPONSE']._serialized_end=335
  _globals['_ASYMMETRICSIGNHASHREQUEST']._serialized_start=337
  _globals['_ASYMMETRICSIGNHASHREQUEST']._serialized_end=424
  _globals['_ASYMMETRICSIGNHASHRESPONSE']._serialized_start=426
  _globals['_ASYMMETRICSIGNHASHRESPONSE']._serialized_end=489
  _globals['_ASYMMETRICGETPUBLICKEYREQUEST']._serialized_start=491
  _globals['_ASYMMETRICGETPUBLICKEYREQUEST']._serialized_end=552
  _globals['_ASYMMETRICGETPUBLICKEYRESPONSE']._serialized_start=554
  _globals['_ASYMMETRICGETPUBLICKEYRESPONSE']._serialized_end=622
  _globals['_ASYMMETRICSIGNATURECRYPTOSERVICE']._serialized_start=625
  _globals['_ASYMMETRICSIGNATURECRYPTOSERVICE']._serialized_end=1289
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.datatransfer.v1.endpoint.parsers_pb2
import yandex.cloud.datatransfer.v1.endpoint.serializers_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _YdsCompressionCodec:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _YdsCompressionCodecEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_YdsCompressionCodec.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    YDS_COMPRESSION_CODEC_UNSPECIFIED: _YdsCompressionCodec.ValueType  # 0
    YDS_COMPRESSION_CODEC_RAW: _YdsCompressionCodec.ValueType  # 1
    YDS_COMPRESSION_CODEC_GZIP: _YdsCompressionCodec.ValueType  # 2
    YDS_COMPRESSION_CODEC_ZSTD: _YdsCompressionCodec.ValueType  # 4

class YdsCompressionCodec(_YdsCompressionCodec, metaclass=_YdsCompressionCodecEnumTypeWrapper): ...

YDS_COMPRESSION_CODEC_UNSPECIFIED: YdsCompressionCodec.ValueType  # 0
YDS_COMPRESSION_CODEC_RAW: YdsCompressionCodec.ValueType  # 1
YDS_COMPRESSION_CODEC_GZIP: YdsCompressionCodec.ValueType  # 2
YDS_COMPRESSION_CODEC_ZSTD: YdsCompressionCodec.ValueType  # 4
global___YdsCompressionCodec = YdsCompressionCodec

@typing.final
class YDSSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    SUPPORTED_CODECS_FIELD_NUMBER: builtins.int
    PARSER_FIELD_NUMBER: builtins.int
    ALLOW_TTL_REWIND_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    CONSUMER_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database"""
    stream: builtins.str
    """Stream"""
    service_account_id: builtins.str
    """SA which has read access to the stream."""
    allow_ttl_rewind: builtins.bool
    """Should continue working, if consumer read lag exceed TTL of topic
    False: stop the transfer in error state, if detected lost data. True: continue
    working with losing part of data
    """
    endpoint: builtins.str
    """for dedicated db"""
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    consumer: builtins.str
    """for important streams"""
    @property
    def supported_codecs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___YdsCompressionCodec.ValueType]:
        """Compression codec"""

    @property
    def parser(self) -> yandex.cloud.datatransfer.v1.endpoint.parsers_pb2.Parser:
        """Data parsing rules"""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        database: builtins.str = ...,
        stream: builtins.str = ...,
        service_account_id: builtins.str = ...,
        supported_codecs: collections.abc.Iterable[global___YdsCompressionCodec.ValueType] | None = ...,
        parser: yandex.cloud.datatransfer.v1.endpoint.parsers_pb2.Parser | None = ...,
        allow_ttl_rewind: builtins.bool = ...,
        endpoint: builtins.str = ...,
        subnet_id: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        consumer: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["parser", b"parser"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allow_ttl_rewind", b"allow_ttl_rewind", "consumer", b"consumer", "database", b"database", "endpoint", b"endpoint", "parser", b"parser", "security_groups", b"security_groups", "service_account_id", b"service_account_id", "stream", b"stream", "subnet_id", b"subnet_id", "supported_codecs", b"supported_codecs"]) -> None: ...

global___YDSSource = YDSSource

@typing.final
class YDSTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    SAVE_TX_ORDER_FIELD_NUMBER: builtins.int
    SERIALIZER_FIELD_NUMBER: builtins.int
    ENDPOINT_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Database"""
    stream: builtins.str
    """Stream"""
    service_account_id: builtins.str
    """SA which has read access to the stream."""
    save_tx_order: builtins.bool
    """Save transaction order
    Not to split events queue into separate per-table queues.
    Incompatible with setting Topic prefix, only with Topic full name.
    """
    endpoint: builtins.str
    """for dedicated db"""
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    @property
    def serializer(self) -> yandex.cloud.datatransfer.v1.endpoint.serializers_pb2.Serializer:
        """Data serialization format"""

    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        database: builtins.str = ...,
        stream: builtins.str = ...,
        service_account_id: builtins.str = ...,
        save_tx_order: builtins.bool = ...,
        serializer: yandex.cloud.datatransfer.v1.endpoint.serializers_pb2.Serializer | None = ...,
        endpoint: builtins.str = ...,
        subnet_id: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["serializer", b"serializer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["database", b"database", "endpoint", b"endpoint", "save_tx_order", b"save_tx_order", "security_groups", b"security_groups", "serializer", b"serializer", "service_account_id", b"service_account_id", "stream", b"stream", "subnet_id", b"subnet_id"]) -> None: ...

global___YDSTarget = YDSTarget



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.iam.v1.refresh_token_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RevokeRefreshTokenMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_IDS_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    @property
    def refresh_token_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Id of revoked Refresh Tokens."""

    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
        refresh_token_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["refresh_token_ids", b"refresh_token_ids", "subject_id", b"subject_id"]) -> None: ...

global___RevokeRefreshTokenMetadata = RevokeRefreshTokenMetadata

@typing.final
class ListRefreshTokensRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    subject_id: builtins.str
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListRefreshTokensResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListRefreshTokensResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters refresh tokens listed in the response.

    The expression must specify:
    1. The field name. Currently you can use filtering only on [RefreshToken.client_instance_info], [RefreshToken.client_id] or [RefreshToken.protection_level] fields.
    2. The operator. An `=` operator can be used for all fields. An 'IN' operator can be used for [RefreshToken.protection_level].
    3. The value. The value must be in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-zA-Z][_-a-zA-Z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `client_instance_info="clientInstanceInfo" AND protection_level IN ("INSECURE_KEY_DPOP", "SECURE_KEY_DPOP")`.
    """
    def __init__(
        self,
        *,
        subject_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "subject_id", b"subject_id"]) -> None: ...

global___ListRefreshTokensRequest = ListRefreshTokensRequest

@typing.final
class ListRefreshTokensResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REFRESH_TOKENS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListRefreshTokensForSubjectRequest.page_size], use
    the [next_page_token] as the value
    for the [ListRefreshTokensForSubjectRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def refresh_tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.iam.v1.refresh_token_pb2.RefreshToken]:
        """List of Refresh Tokens"""

    def __init__(
        self,
        *,
        refresh_tokens: collections.abc.Iterable[yandex.cloud.iam.v1.refresh_token_pb2.RefreshToken] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "refresh_tokens", b"refresh_tokens"]) -> None: ...

global___ListRefreshTokensResponse = ListRefreshTokensResponse

@typing.final
class RevokeRefreshTokenRequest(google.protobuf.message.Message):
    """Revoke Refresh Token request.
    If none of the parameters refresh_token_id, refresh_token, or revoke_filter are provided, all Refresh Tokens for the current subject will be revoked.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REFRESH_TOKEN_ID_FIELD_NUMBER: builtins.int
    REFRESH_TOKEN_FIELD_NUMBER: builtins.int
    REVOKE_FILTER_FIELD_NUMBER: builtins.int
    refresh_token_id: builtins.str
    """Identifier of the Refresh Token to be revoked."""
    refresh_token: builtins.str
    """The Refresh Token to be revoked."""
    @property
    def revoke_filter(self) -> global___RevokeFilter:
        """The filter for revoking Refresh Token"""

    def __init__(
        self,
        *,
        refresh_token_id: builtins.str = ...,
        refresh_token: builtins.str = ...,
        revoke_filter: global___RevokeFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter", "refresh_token", b"refresh_token", "refresh_token_id", b"refresh_token_id", "revoke_filter", b"revoke_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "refresh_token", b"refresh_token", "refresh_token_id", b"refresh_token_id", "revoke_filter", b"revoke_filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["filter", b"filter"]) -> typing.Literal["refresh_token_id", "refresh_token", "revoke_filter"] | None: ...

global___RevokeRefreshTokenRequest = RevokeRefreshTokenRequest

@typing.final
class RevokeFilter(google.protobuf.message.Message):
    """The Filter object allows filtering Refresh Tokens that will be revoked.
    It contains three optional fields.
    When multiple fields are provided, they are combined using a logical AND operation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_ID_FIELD_NUMBER: builtins.int
    SUBJECT_ID_FIELD_NUMBER: builtins.int
    CLIENT_INSTANCE_INFO_FIELD_NUMBER: builtins.int
    client_id: builtins.str
    """The OAuth client identifier for which the Refresh Token was issued."""
    subject_id: builtins.str
    """The subject identifier for whom the Refresh Token was issued.
    If not specified, it defaults to the subject that made the request.
    """
    client_instance_info: builtins.str
    """Information about the app for which the Refresh Token was issued."""
    def __init__(
        self,
        *,
        client_id: builtins.str = ...,
        subject_id: builtins.str = ...,
        client_instance_info: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["client_id", b"client_id", "client_instance_info", b"client_instance_info", "subject_id", b"subject_id"]) -> None: ...

global___RevokeFilter = RevokeFilter

@typing.final
class RevokeRefreshTokenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REFRESH_TOKEN_IDS_FIELD_NUMBER: builtins.int
    @property
    def refresh_token_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Id of revoked Refresh Tokens."""

    def __init__(
        self,
        *,
        refresh_token_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["refresh_token_ids", b"refresh_token_ids"]) -> None: ...

global___RevokeRefreshTokenResponse = RevokeRefreshTokenResponse
